@@ -1,8 +1,4 @@
-from __future__ import print_function
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
+# coding=utf-8
 from blueman.services.meta import SerialService
 from blueman.Sdp import SERIAL_PORT_SVCLASS_ID
 
